<?php

class Profil extends Model { // classe de modèle pour l'affichage de profils
	public $slug, $pseudo, $password, $nom, $prenom, $email, $description, $avatar; // on définit les attributs de la classe
	
	public static function getFromSlug($slug_profil) { // méthode permettant de récupérer les informations relatives à un profil donné de la BDD
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur WHERE slug = :slug"; // on définit la requête qu'on enverra
		$req = $db->prepare($sql); // on prépare la requête (c'est là que la mémthode __call() est utile dans la classe Database d'ailleurs)
		$req->setFetchMode(PDO::FETCH_CLASS, "Profil");  // règle le type dans lequel on doit mettre les données (PDO va chercher les attributs de la classe de même nom que ses colonnes de BDD et mettre dedans les valeurs correspondantes)
		$req->execute(array(":slug" => $slug_profil)); // on remplace le "::slug" par sa valeur dans la requête
		return $req->fetch(); // on retourne le premier (et normalement unique) résultat en BDD
	}
	
	public static function getList() { // méthode permettant de récupérer la liste des profils de la BDD
		$db = Database::getInstance(); // idem à au-dessus
		$sql = "SELECT * FROM R_joueur";
		$req = $db->query($sql);
		$req->setFetchMode(PDO::FETCH_CLASS, "Profil");
		return $req->fetchAll();
	}
	
	public static function setPassword($slug, $password) {
		$db = Database::getInstance(); // idem à au-dessus
		$sql = "UPDATE R_joueur SET password = :password WHERE slug = :slug";
		$req = $db->prepare($sql);
		$req->execute(array(':password' => $password, ':slug' => $slug));
	}
	
	public static function setAutre($slug, $data)
	{
		$db = Database::getInstance(); // idem à au-dessus
		$sql = "UPDATE R_joueur SET nom = :nom, prenom = :prenom, email = :email, avatar = :avatar WHERE slug = :slug";
		$req = $db->prepare($sql);
		$req->execute(array(':nom' => $data['nom'],
			':prenom' => $data['prenom'],
			':email' => $data['email'],
			':avatar' => $data['avatar'],
			':slug' => $slug));
	}
	
	public static function getLastMember() { // méthode permettant de récupérer les informations relatives au dernier membre inscrit en BDD
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur"; // on définit la requête qu'on enverra
		$req = $db->query($sql); // on exécute la requête
		$req->setFetchMode(PDO::FETCH_CLASS, "Profil");  // règle le type dans lequel on doit mettre les données (PDO va chercher les attributs de la classe de même nom que ses colonnes de BDD et mettre dedans les valeurs correspondantes)
		$ret = null;
		while ($elt = $req->fetch()) { // on parcourt tous les résultats et on les stocke au fur et à mesure dans la même variable, jusqu'au dernier. C'est lui qui restera à la fin
			$ret = $elt;
		}
		return $ret; // on retourne les données du membre
	}
	
	public static function getNbMembers()
	{ // méthode permettant de récupérer les informations relatives au dernier membre inscrit en BDD
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT COUNT(*) FROM R_joueur"; // on définit la requête qu'on enverra
		$req = $db->query($sql); // on exécute la requête
		return $req->fetch()[0]; // on retourne le nombre
	}
	
	public static function checkExists($slug_profil) { // méthode permettant de vérifier si un profil existe dans la BDD
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur WHERE slug = :slug";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":slug" => $slug_profil)); // on remplace les variables dans la requête

		if($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
			return 1;
		}

		return 0; // on aurait pu mettre deux return (un dans le if et un ici), mais bon...
	}
	
	public static function checkJeuFavoris($slug_joueur, $slug_jeu) { // méthode permettant de vérifier si un jeu est jeu favoris d'un joueur
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur_jeu WHERE joueur = :slug_j AND jeu = :slug_jeu AND est_jeu_favoris";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":slug_j" => $slug_joueur, ":slug_jeu" => $slug_jeu)); // on remplace les variables dans la requête

		if($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
			return 1;
		}
		return 0;
	}
	
	public static function checkADejaJoue($slug_joueur, $slug_jeu) { // méthode permettant de vérifier si un joueur a déjà joué à un jeu
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur_jeu WHERE joueur = :slug_j AND jeu = :slug_jeu";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":slug_j" => $slug_joueur, ":slug_jeu" => $slug_jeu)); // on remplace les variables dans la requête

		if($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
			return 1;
		}
		return 0;
	}
	
	public static function upadteJeuFavoris($slug_joueur, $slug_jeu, $favoris) { // méthode permettant de définir un jeu comme étant jeu favoris d'un joueur, ou l'inverse
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "UPDATE R_joueur_jeu SET est_jeu_favoris = :favoris WHERE joueur = :slug_j AND jeu = :slug_jeu";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":favoris" => $favoris, ":slug_j" => $slug_joueur, ":slug_jeu" => $slug_jeu)); // on remplace les variables dans la requête
	}
	
	public static function insertJeuFavoris($slug_joueur, $slug_jeu, $favoris) { // méthode permettant de définir un jeu comme étant jeu favoris d'un joueur, ou l'inverse
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "INSERT INTO R_joueur_jeu VALUES (:slug_joueur, :slug_jeu, null, null, :favoris) ";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":slug_joueur" => $slug_joueur, ":slug_jeu" => $slug_jeu, ":favoris" => $favoris)); // on remplace les variables dans la requête
	}
}



