<?php

class Register extends Model { // classe de modèle pour l'inscription
	public static function checkPseudo($slug_joueur) { // méthode permettant de vérifier si un pseudo est libre
		
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur WHERE slug = :slug";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":slug" => $slug_joueur)); // on remplace les variables dans la requête
		
		if($result = $req->fetch()) { // si un enregistrement existe en BDD, on retourne 0
			return 0;
		}
		
		return 1; // sinon : OK -> on retourne  1
	}
	
	public static function checkEmail($email) { // méthode permettant de vérifier si un pseudo est libre
		
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur WHERE email = :email";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":email" => $email)); // on remplace les variables dans la requête
		
		if($result = $req->fetch()) { // si un enregistrement existe en BDD, on retourne 0
			return 0;
		}
		
		return 1; // sinon : OK -> on retourne  1
	}
	
	public static function check($slug_joueur, $email) { // méthode permettant de vérifier si un compte-joueur est libre
		// OK si personne avec même pseudo ou même adresse mail n'existe dans la BDD
		// renvoie 1 si le compte est libre (= n'existe pas)
		// renvoie 2 si pseudo déjà pris
		// renvoie 3 si email déjà utilisé
		
		$db = Database::getInstance(); // on récupère la connexion à la BDD
		$sql = "SELECT * FROM R_joueur WHERE slug = :slug OR email = :email";
		$req = $db->prepare($sql); // on prépare la requête
		$req->execute(array(":slug" => $slug_joueur, ":email" => $email)); // on remplace les variables dans la requête
		
		$return = 1; //valeur par défaut si on n'a pas d'autre 
		if($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
			if($result["slug"] == $slug_joueur) {
				$return = 2;
			} // si on a trouvé quelqu'un avec le pseudo, on ne peut pas faire l'inscription
			else if($result["email"] == $email) {
				$return = 3;
			} // si on a trouvé quelqu'un avec l'e-mail, on ne peut pas faire l'inscription
		}
		
		return $return; // on aurait pu mettre deux return (un dans le if et un ici), mais bon...
	}

	public static function writedb($data) { // méthode réalisant l'inscription dans la BDD à partir d'un tableau de données
		$db = Database::getInstance(); // on récupère la connexion à la BDD

		$sql = "INSERT INTO R_joueur (slug, pseudo, password, nom, prenom, email, description, avatar) VALUES (:slug, :pseudo, :password, :nom, :prenom, :email, :description, :avatar)";
		$req = $db->prepare($sql); // on prépare la requête
		$result = $req->execute(array(":slug" 		=> $data['slug_joueur'],
										":pseudo" 	=> $data['pseudo'],
										":password" => $data['password'],
										":nom" 		=> $data['nom'],
									  	":prenom" 	=> $data['prenom'],
									  	":email" 	=> $data['email'],
									  	":description" => $data['description'],
										":avatar" => $data['avatar'])); // on remplace les variables dans la requête

		return $result; // on aurait pu mettre deux return (un dans le if et un ici), mais bon...
	}
}



